package io.scanbot.barcodesdk.plugin.reactnative.components.barcode_scanner_view

import com.facebook.react.bridge.Arguments
import com.facebook.react.bridge.WritableMap
import io.scanbot.sdk.barcode.BarcodeItem
import io.scanbot.sdk.barcode.BarcodeScannerResult
import io.scanbot.sdk.reactnative.extensions.toWritableArray
import io.scanbot.sdk.reactnative.extensions.toWritableMap
import io.scanbot.sdk.reactnative.models.BaseEvent
import org.json.JSONArray

class BarcodeScannerResultEvent(private val barcodeResult: BarcodeScannerResult) : BaseEvent {

    companion object {
        const val NAME = "barcodeScannerResult"
    }

    override val eventName = NAME

    override fun parseData(): WritableMap {
        return Arguments.createMap().apply {
            // Cannot use .use because same barcodeItem reference is used in BarcodeSelectionResultEvent
            val barcodeItems = barcodeResult.barcodes.map { item -> item.toJson() }

            putArray("result", JSONArray(barcodeItems).toWritableArray())
        }
    }
}

class BarcodeSelectionResultEvent(private val barcodeItem: BarcodeItem) : BaseEvent {

    companion object {
        const val NAME = "selectBarcodeResult"
    }

    override val eventName = NAME

    override fun parseData(): WritableMap {
        return Arguments.createMap().apply {
            // Cannot use .use because same barcodeItem can be pressed twice
            putMap("result", barcodeItem.toJson().toWritableMap())
        }
    }
}
