"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DocumentDataFrameExtractionParameters = exports.DocumentDataExtractorConfiguration = exports.DocumentDataExtractionStatusValues = exports.DocumentDataExtractionResult = exports.DocumentDataExtractionModeValues = void 0;
var _DocumentDataExtractorConfigurationTypes = require("../document_data_extractor/DocumentDataExtractorConfigurationTypes");
var _DocumentScannerTypes = require("../document_scanner/DocumentScannerTypes");
var _GenericDocument = require("../documents/GenericDocument");
var _FrameAccumulationTypes = require("../frame_accumulation/FrameAccumulationTypes");
var _image = require("../imageRef/image");
var _JsonSerializationTypes = require("../utils/json/JsonSerializationTypes");
var _utils = require("../utils/utils");
/// Auto-generated with ScanbotSDKCodegenV3. Modifications will be overwritten.
/// Generated from core/schemas/DocumentDataExtractorTypes.yaml

/**
The status of the extraction process.

- `SUCCESS`:
   The document was extracted successfully.
- `ERROR_NOTHING_FOUND`:
   No document was detected.
- `ERROR_BAD_CROP`:
   A document was detected, but it was at an angle/distance that was too large.
- `ERROR_UNKNOWN_DOCUMENT`:
   A document was detected, but it was not extracted as a supported document.
- `ERROR_UNACCEPTABLE_DOCUMENT`:
   A document was detected as a supported document, but it was not part of the accepted documents.
- `INCOMPLETE_VALIDATION`:
   All fields were extracted, but some of them failed validation.
*/

const DocumentDataExtractionStatusValues = exports.DocumentDataExtractionStatusValues = ['SUCCESS', 'ERROR_NOTHING_FOUND', 'ERROR_BAD_CROP', 'ERROR_UNKNOWN_DOCUMENT', 'ERROR_UNACCEPTABLE_DOCUMENT', 'INCOMPLETE_VALIDATION'];

/**
Contains the result of running the generic document extractor.
*/
class DocumentDataExtractionResult extends _utils.PartiallyConstructible {
  /**
    The status of the extraction process.
    */

  /**
    The extracted document.
    */

  /**
    Result of the document detection in the input image.
    */

  /**
    Crop of the document if it was detected.
    */
  croppedImage = null;

  /** @param source {@displayType `DeepPartial<DocumentDataExtractionResult>`} */
  constructor(source = {}) {
    super();
    if (source.status !== undefined) {
      this.status = source.status;
    } else {
      throw new Error('status must be present in constructor argument');
    }
    if (source.document !== undefined) {
      this.document = source.document != null ? new _GenericDocument.GenericDocument(source.document) : null;
    } else {
      throw new Error('document must be present in constructor argument');
    }
    if (source.documentDetectionResult !== undefined) {
      this.documentDetectionResult = new _DocumentScannerTypes.DocumentDetectionResult(source.documentDetectionResult);
    } else {
      throw new Error('documentDetectionResult must be present in constructor argument');
    }
    if (source.croppedImage !== undefined) {
      this.croppedImage = source.croppedImage != null ? _image.ImageRef.From(source.croppedImage) : null;
    }
  }
  async serialize(config = new _JsonSerializationTypes.ToJsonConfiguration()) {
    return {
      status: this.status,
      document: this.document != null ? await this.document.serialize(config) : null,
      documentDetectionResult: this.documentDetectionResult.serialize(config),
      croppedImage: config.serializeImages ? this.croppedImage != null ? await this.croppedImage.serialize(config.imageSerializationMode) : null : undefined
    };
  }
  _released = false;
  release() {
    if (this._released) {
      return;
    }
    {
      if (this.document != null) {
        this.document.release();
      }
    }
    {
      if (this.croppedImage != null) {
        this.croppedImage.release();
      }
    }
    this._released = true;
  }
  async encodeImages() {
    if (this.document != null) {
      await this.document.encodeImages();
    }
    if (this.croppedImage != null) {
      await this.croppedImage.encodeInPlace();
    }
  }
}

/**
The extraction mode.

- `LIVE`:
   The extractor will attempt to accumulate results over multiple frames.
- `SINGLE_SHOT`:
   The extractor will only use the current frame and will spend additional time to ensure the best possible result.
*/
exports.DocumentDataExtractionResult = DocumentDataExtractionResult;
const DocumentDataExtractionModeValues = exports.DocumentDataExtractionModeValues = ['LIVE', 'SINGLE_SHOT'];

/**
Parameters for the extraction process.
*/
class DocumentDataFrameExtractionParameters extends _utils.PartiallyConstructible {
  /**
    The extraction mode.
    
    Default is LIVE
    */
  mode = 'LIVE';

  /** @param source {@displayType `DeepPartial<DocumentDataFrameExtractionParameters>`} */
  constructor(source = {}) {
    super();
    if (source.mode !== undefined) {
      this.mode = source.mode;
    }
  }
}

/**
Configuration for the document data extractor.
*/
exports.DocumentDataFrameExtractionParameters = DocumentDataFrameExtractionParameters;
class DocumentDataExtractorConfiguration extends _utils.PartiallyConstructible {
  /**
    Configuration for how to accumulate results.
    */
  resultAccumulationConfig = new _FrameAccumulationTypes.ResultAccumulationConfiguration({});
  /**
    Normalized names of the fields to exclude from the result.
    */
  fieldExcludeList = [];
  /**
    List of configuration elements for the document data extractor.
    */

  /**
    If true, crops of the detected documents and fields will be returned in the result.
    
    Default is false
    */
  returnCrops = false;

  /** @param source {@displayType `DeepPartial<DocumentDataExtractorConfiguration>`} */
  constructor(source = {}) {
    super();
    if (source.resultAccumulationConfig !== undefined) {
      this.resultAccumulationConfig = new _FrameAccumulationTypes.ResultAccumulationConfiguration(source.resultAccumulationConfig);
    }
    if (source.fieldExcludeList !== undefined) {
      this.fieldExcludeList = source.fieldExcludeList.map(it => {
        return it;
      });
    }
    if (source.configurations !== undefined) {
      this.configurations = source.configurations.map(it => {
        return _DocumentDataExtractorConfigurationTypes.DocumentDataExtractorConfigurationElement.From(it);
      });
    } else {
      throw new Error('configurations must be present in constructor argument');
    }
    if (source.returnCrops !== undefined) {
      this.returnCrops = source.returnCrops;
    }
  }
}
exports.DocumentDataExtractorConfiguration = DocumentDataExtractorConfiguration;
//# sourceMappingURL=DocumentDataExtractorTypes.js.map