"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.VinScannerResult = exports.VinBarcodeResult = exports.VinBarcodeExtractionStatusValues = void 0;
var _TextPatternScannerTypes = require("../text_pattern_scanner/TextPatternScannerTypes");
var _JsonSerializationTypes = require("../utils/json/JsonSerializationTypes");
var _utils = require("../utils/utils");
/// Auto-generated with ScanbotSDKCodegenV3. Modifications will be overwritten.
/// Generated from core/schemas/VINScannerTypes.yaml

/**
Status of the barcode extraction.

- `SUCCESS`:
   Barcode containing a VIN was successfully extracted.
- `BARCODE_WITHOUT_VIN`:
   Barcode was found but it does not contain a VIN.
- `NO_BARCODE_FOUND`:
   No barcode was found in the image.
- `BARCODE_EXTRACTION_DISABLED`:
   Barcode extraction is disabled in the configuration.
*/

const VinBarcodeExtractionStatusValues = exports.VinBarcodeExtractionStatusValues = ['SUCCESS', 'BARCODE_WITHOUT_VIN', 'NO_BARCODE_FOUND', 'BARCODE_EXTRACTION_DISABLED'];

/**
Result of the barcode scanner.
*/
class VinBarcodeResult extends _utils.PartiallyConstructible {
  /**
    Text result of the barcode scanner.
    */

  /**
    Rectangle of the barcode in the image.
    */

  /**
    Status of the barcode extraction.
    */

  /** @param source {@displayType `DeepPartial<VinBarcodeResult>`} */
  constructor(source = {}) {
    super();
    if (source.extractedVIN !== undefined) {
      this.extractedVIN = source.extractedVIN;
    } else {
      throw new Error('extractedVIN must be present in constructor argument');
    }
    if (source.rectangle !== undefined) {
      this.rectangle = source.rectangle.map(it => {
        return {
          x: it.x,
          y: it.y
        };
      });
    } else {
      throw new Error('rectangle must be present in constructor argument');
    }
    if (source.status !== undefined) {
      this.status = source.status;
    } else {
      throw new Error('status must be present in constructor argument');
    }
  }
  serialize(config = new _JsonSerializationTypes.ToJsonConfiguration()) {
    return {
      extractedVIN: this.extractedVIN,
      rectangle: this.rectangle.map(it => {
        return it;
      }),
      status: this.status
    };
  }
}

/**
Result of the VIN scanner.
*/
exports.VinBarcodeResult = VinBarcodeResult;
class VinScannerResult extends _utils.PartiallyConstructible {
  /**
    Text result of the VIN scanner.
    */

  /**
    Barcode result of the VIN scanner.
    */

  /** @param source {@displayType `DeepPartial<VinScannerResult>`} */
  constructor(source = {}) {
    super();
    if (source.textResult !== undefined) {
      this.textResult = new _TextPatternScannerTypes.TextPatternScannerResult(source.textResult);
    } else {
      throw new Error('textResult must be present in constructor argument');
    }
    if (source.barcodeResult !== undefined) {
      this.barcodeResult = new VinBarcodeResult(source.barcodeResult);
    } else {
      throw new Error('barcodeResult must be present in constructor argument');
    }
  }
  serialize(config = new _JsonSerializationTypes.ToJsonConfiguration()) {
    return {
      textResult: this.textResult.serialize(config),
      barcodeResult: this.barcodeResult.serialize(config)
    };
  }
}
exports.VinScannerResult = VinScannerResult;
//# sourceMappingURL=VinScannerTypes.js.map