import React, { forwardRef, useCallback, useImperativeHandle, useRef } from 'react';
import { Platform, StyleSheet, View } from 'react-native';
import { BarcodeItem } from '../../barcode';
import { autorelease } from '../../imageRef';
import NativeBarcodeCameraView, { Commands } from '../spec/ScanbotBarcodeScannerViewNativeComponent';
export const ScanbotBarcodeCameraView = /*#__PURE__*/forwardRef(({
  onBarcodeScannerResult,
  ...props
}, forwardedRef) => {
  const viewRef = useRef(null);
  const boundBarcodeItemOverlayViews = useRef(new Map());
  const barcodeFormatsContainer = {
    _type: undefined,
    regexFilter: undefined,
    minimumSizeScore: undefined,
    addAdditionalQuietZone: undefined,
    minimum1DQuietZoneSize: undefined,
    minimumTextLength: undefined,
    maximumTextLength: undefined,
    returnStartEnd: undefined,
    stripCheckDigits: undefined,
    checksum: undefined,
    code32: undefined,
    code39: undefined,
    pzn7: undefined,
    pzn8: undefined,
    tryCode39ExtendedMode: undefined,
    useCode39CheckDigit: undefined,
    gs1Handling: undefined,
    iata2of5: undefined,
    code25: undefined,
    industrial2of5: undefined,
    useIATA2OF5Checksum: undefined,
    checksumAlgorithms: undefined,
    ean8: undefined,
    ean13: undefined,
    upca: undefined,
    upce: undefined,
    extensions: undefined,
    minimumValue: undefined,
    allowNarrowBarsOnly: undefined,
    allowWideBarsOnly: undefined,
    strictMode: undefined,
    qr: undefined,
    microQr: undefined,
    rmqr: undefined,
    australiaPostCustomerFormat: undefined,
    formats: undefined
  };
  useImperativeHandle(forwardedRef, () => {
    return {
      freezeCamera() {
        if (viewRef.current) {
          Commands.freezeCamera(viewRef.current);
        }
      },
      unfreezeCamera() {
        if (viewRef.current) {
          Commands.unfreezeCamera(viewRef.current);
        }
      }
    };
  }, []);
  const _onBarcodeScannerResult = useCallback(async event => {
    const result = event.nativeEvent.result;
    const selectionOverlayAutoSelectDisabled = props.selectionOverlayConfig?.overlayEnabled && !props.selectionOverlayConfig?.automaticSelectionEnabled;
    if (result) {
      const barcodeItems = Platform.OS === 'ios' ? JSON.parse(result) : result;
      if (!selectionOverlayAutoSelectDisabled) {
        autorelease(() => {
          onBarcodeScannerResult(barcodeItems.map(item => new BarcodeItem(item)));
        });
      }
      if (props.selectionOverlayConfig?.barcodeItemOverlayViewBinder) {
        for (let barcode of barcodeItems) {
          const barcodeItemUuid = barcode.text + barcode.upcEanExtension + '_' + barcode.format;
          const barcodeItemNextBind = boundBarcodeItemOverlayViews.current.get(barcodeItemUuid);
          if (barcodeItemNextBind === undefined || barcodeItemNextBind !== -1 && Date.now() >= barcodeItemNextBind) {
            boundBarcodeItemOverlayViews.current.set(barcodeItemUuid, -1);
            const bindingConfig = await props.selectionOverlayConfig.barcodeItemOverlayViewBinder(barcode);
            if (bindingConfig.refreshRate !== undefined && bindingConfig.refreshRate > 0) {
              boundBarcodeItemOverlayViews.current.set(barcodeItemUuid, Date.now() + bindingConfig.refreshRate);
            }
            if (viewRef.current != null) {
              Commands.bindBarcodeItemOverlayView(viewRef.current, barcodeItemUuid, JSON.stringify(bindingConfig));
            }
          }
        }
      }
    }
  }, [props.selectionOverlayConfig, boundBarcodeItemOverlayViews, onBarcodeScannerResult]);
  const _onBarcodeSelectionResult = useCallback(event => {
    const result = event.nativeEvent.result;
    const selectionOverlayAutoSelectDisabled = props.selectionOverlayConfig?.overlayEnabled && !props.selectionOverlayConfig?.automaticSelectionEnabled;
    if (selectionOverlayAutoSelectDisabled && result) {
      let barcodeItems;
      if (Platform.OS === 'ios') {
        const parsedResult = JSON.parse(result);
        barcodeItems = parsedResult.map(item => new BarcodeItem(item));
      } else {
        barcodeItems = [new BarcodeItem(result)];
      }
      autorelease(() => {
        onBarcodeScannerResult(barcodeItems);
      });
    }
  }, [onBarcodeScannerResult, props.selectionOverlayConfig?.automaticSelectionEnabled, props.selectionOverlayConfig?.overlayEnabled]);
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.container, props.style]
  }, /*#__PURE__*/React.createElement(View, {
    pointerEvents: 'box-none',
    style: [styles.contentContainerStyle, props.contentContainerStyle]
  }, props.children), /*#__PURE__*/React.createElement(NativeBarcodeCameraView
  //FinderConfigs
  , {
    finderEnabled: props.finderConfig?.viewFinderEnabled,
    finderStrokeWidth: props.finderConfig?.finderLineWidth,
    finderMinPadding: props.finderConfig?.minPadding,
    finderStrokeColor: props.finderConfig?.finderLineColor,
    finderOverlayColor: props.finderConfig?.overlayColor,
    finderInset: props.finderConfig?.finderInset,
    finderRequiredAspectRatios: props.finderConfig?.requiredAspectRatio
    //CameraConfigs
    ,
    cameraZoomFactor: Platform.select({
      ios: props.cameraConfig?.cameraZoomFactor ? parseFloat(props.cameraConfig?.cameraZoomFactor.toFixed(2)) : undefined,
      android: props.cameraConfig?.cameraZoomFactor !== undefined ? (props.cameraConfig?.cameraZoomRange?.minZoom || 1) + ((props.cameraConfig?.cameraZoomRange?.maxZoom || 12) - (props.cameraConfig?.cameraZoomRange?.minZoom || 1)) * props.cameraConfig?.cameraZoomFactor : undefined
    }),
    cameraZoomRange: props.cameraConfig?.cameraZoomRange,
    minFocusDistanceLock: props.cameraConfig?.minFocusDistanceLock,
    cameraModule: props.cameraConfig?.cameraModule
    //SelectionOverlayConfig
    ,
    overlayEnabled: props.selectionOverlayConfig?.overlayEnabled,
    overlayPolygonColor: props.selectionOverlayConfig?.polygonColor,
    overlayStrokeColor: props.selectionOverlayConfig?.strokeColor,
    overlayTextFormat: props.selectionOverlayConfig?.textFormat,
    overlayTextColor: props.selectionOverlayConfig?.textColor,
    overlayTextContainerColor: props.selectionOverlayConfig?.textContainerColor,
    overlayLoadingTextValue: props.selectionOverlayConfig?.loadingTextValue,
    overlayBarcodeItemOverlayViewBinder: props.selectionOverlayConfig?.barcodeItemOverlayViewBinder !== undefined
    //Barcode Scanner Configuration
    ,
    configFormatConfigurations: props.barcodeScannerConfiguration?.barcodeFormatConfigurations?.map(config => ({
      ...barcodeFormatsContainer,
      ...config
    })),
    configExtractedDocumentFormats: props.barcodeScannerConfiguration?.extractedDocumentFormats,
    configOnlyAcceptDocuments: props.barcodeScannerConfiguration?.onlyAcceptDocuments,
    configReturnBarcodeImage: props.barcodeScannerConfiguration?.returnBarcodeImage,
    configEngineMode: props.barcodeScannerConfiguration?.engineMode
    //Other
    ,
    flashEnabled: props.flashEnabled,
    scanningEnabled: props.scanningEnabled,
    hardwareButtonsEnabled: props.hardwareButtonsEnabled
    //View
    ,
    style: styles.container,
    ref: viewRef
    //Result
    ,
    onBarcodeScannerResult: _onBarcodeScannerResult,
    onSelectBarcodeResult: _onBarcodeSelectionResult
  }));
});
const styles = StyleSheet.create({
  container: {
    flex: 1
  },
  contentContainerStyle: {
    position: 'absolute',
    width: '100%',
    height: '100%',
    zIndex: 2
  }
});
//# sourceMappingURL=ScanbotBarcodeCameraView.js.map