import { ButtonConfiguration, StyledText } from '../../ui_v2/common/Common';
import { DeepPartial, PartiallyConstructible } from '../../utils/utils';
/**
The image for the introduction screen of a credit card scanner screen.
*/
export type CreditCardScannerIntroImage = CreditCardIntroOneSideImage | CreditCardIntroTwoSidesImage | CreditCardNoImage | CreditCardIntroCustomImage;
/**
The image for the introduction screen with one side of a credit card.
*/
export declare class CreditCardIntroOneSideImage extends PartiallyConstructible {
    readonly _type: 'CreditCardIntroOneSideImage';
    /** @param source {@displayType `DeepPartial<CreditCardIntroOneSideImage>`} */
    constructor(source?: DeepPartial<CreditCardIntroOneSideImage>);
}
/**
The image for the introduction screen with two sides of a credit card.
*/
export declare class CreditCardIntroTwoSidesImage extends PartiallyConstructible {
    readonly _type: 'CreditCardIntroTwoSidesImage';
    /** @param source {@displayType `DeepPartial<CreditCardIntroTwoSidesImage>`} */
    constructor(source?: DeepPartial<CreditCardIntroTwoSidesImage>);
}
/**
No image for the introduction screen.
*/
export declare class CreditCardNoImage extends PartiallyConstructible {
    readonly _type: 'CreditCardNoImage';
    /** @param source {@displayType `DeepPartial<CreditCardNoImage>`} */
    constructor(source?: DeepPartial<CreditCardNoImage>);
}
/**
A custom image for the introduction screen.
*/
export declare class CreditCardIntroCustomImage extends PartiallyConstructible {
    readonly _type: 'CreditCardIntroCustomImage';
    /**
      The web or file URI to the image.
      */
    uri: string;
    /** @param source {@displayType `DeepPartial<CreditCardIntroCustomImage>`} */
    constructor(source?: DeepPartial<CreditCardIntroCustomImage>);
}
/**
Configuration of the introduction screen for the credit card scanner.
*/
export declare class CreditCardScannerIntroScreenConfiguration extends PartiallyConstructible {
    /**
      The image for the introduction screen.
      */
    image: CreditCardScannerIntroImage;
    /**
      The background color of the introduction screen.
      
      Default is "?sbColorSurface"
      */
    backgroundColor: string;
    /**
      The divider color of the introduction screen.
      
      Default is "?sbColorOutline"
      */
    dividerColor: string;
    /**
      The handle color of the introduction screen.
      
      Default is "?sbColorOutline"
      */
    handlerColor: string;
    /**
      Determines whether the introduction screen should automatically be shown or not when the scanning session starts.
      
      Default is false
      */
    showAutomatically: boolean;
    /**
      The title of the introduction screen, located in the top bar.
      */
    title: StyledText;
    /**
      The text explanation of the introduction screen.
      */
    explanation: StyledText;
    /**
      Configuration of the 'Done' / 'Start scanning' button.
      */
    doneButton: ButtonConfiguration;
    /** @param source {@displayType `DeepPartial<CreditCardScannerIntroScreenConfiguration>`} */
    constructor(source?: DeepPartial<CreditCardScannerIntroScreenConfiguration>);
}
//# sourceMappingURL=CreditCardScannerIntroScreenConfiguration.d.ts.map