import { CreditCardScannerConfiguration } from '../../credit_card/CreditCardTypes';
import { ActionBarConfiguration } from '../../ui_v2/common/ActionBarConfiguration';
import { CameraConfiguration } from '../../ui_v2/common/CameraConfiguration';
import { CameraPermissionScreen } from '../../ui_v2/common/CameraPermission';
import { IconButton, Palette, Sound, Vibration } from '../../ui_v2/common/Common';
import { ScanCompletionOverlay } from '../../ui_v2/common/ScanCompletionOverlay';
import { TopBarConfiguration } from '../../ui_v2/common/TopBarConfiguration';
import { UserGuidanceConfiguration } from '../../ui_v2/common/UserGuidanceConfiguration';
import { PermanentViewFinderConfiguration } from '../../ui_v2/common/ViewFinderConfiguration';
import { CreditCardScannerIntroScreenConfiguration } from '../../ui_v2/creditcard/CreditCardScannerIntroScreenConfiguration';
import { CreditCardScannerScreenTextLocalization } from '../../ui_v2/creditcard/CreditCardScannerScreenTextLocalization';
import { CreditCardScanGuidanceConfiguration } from '../../ui_v2/creditcard/CreditCardScannerUserGuidance';
import { CreditCardScanningProgressConfiguration } from '../../ui_v2/creditcard/CreditCardScanningProgressConfiguration';
import { DeepPartial, PartiallyConstructible } from '../../utils/utils';
/**
Configuration of the screen for detecting credit card data.
*/
export declare class CreditCardScannerScreenConfiguration extends PartiallyConstructible {
    /**
      Version number of the configuration object.
      
      Default is "1.0"
      */
    readonly version: string;
    /**
      The configuration object should be applied for this screen.
      
      Default is "CreditCardScanner"
      */
    readonly screen: string;
    /**
      Configuration of the all strings for credit card scanner screen.
      */
    localization: CreditCardScannerScreenTextLocalization;
    /**
      Define the screen's base color values from which other colors are derived.
      */
    palette: Palette;
    /**
      The background color of the credit card scanner screen.
      
      Default is "?sbColorSurfaceLow"
      */
    backgroundColor: string;
    /**
      Configuration of the camera behavior.
      */
    cameraConfiguration: CameraConfiguration;
    /**
      Configuration of the dialog for requesting camera permissions.
      */
    cameraPermission: CameraPermissionScreen;
    /**
      Configuration of the top user guidance.
      */
    topUserGuidance: UserGuidanceConfiguration;
    /**
      Configuration of the user guidance for the scanning status.
      */
    scanStatusUserGuidance: CreditCardScanGuidanceConfiguration;
    /**
      Configuration of the top bar on the credit card scanner screen.
      */
    topBar: TopBarConfiguration;
    /**
      Configuration of the button in the top bar that opens the introduction screen.
      */
    topBarOpenIntroScreenButton: IconButton;
    /**
      Configuration of the introduction screen for the credit card scanner.
      */
    introScreen: CreditCardScannerIntroScreenConfiguration;
    /**
      Configuration of the action bar.
      */
    actionBar: ActionBarConfiguration;
    /**
      Configuration of the view finder.
      */
    viewFinder: PermanentViewFinderConfiguration;
    /**
      Configuration for the credit card recognizer.
      */
    scannerConfiguration: CreditCardScannerConfiguration;
    /**
      Flag to show or hide the preset button.
      
      Default is true
      */
    exampleOverlayVisible: boolean;
    /**
      Configuration of visualization of the scanning progress.
      */
    scanningProgress: CreditCardScanningProgressConfiguration;
    /**
      Timeout for the scan process. If the scan process takes longer than this value, the incomplete result will be returned.
      
      Default is 3000
      */
    scanIncompleteDataTimeout: number;
    /**
      Configuration of the success overlay.
      */
    successOverlay: ScanCompletionOverlay;
    /**
      Configuration of the success overlay.
      */
    incompleteDataOverlay: ScanCompletionOverlay;
    /**
      Configuration of the scan confirmation sound.
      */
    sound: Sound;
    /**
      Configuration of the vibration feedback.
      */
    vibration: Vibration;
    /**
      If enabled, the screen will not turn off while the barcode scanner is active. (Android only).
      
      Default is true
      */
    keepScreenOn: boolean;
    /** @param source {@displayType `DeepPartial<CreditCardScannerScreenConfiguration>`} */
    constructor(source?: DeepPartial<CreditCardScannerScreenConfiguration>);
}
//# sourceMappingURL=CreditCardScannerScreenConfiguration.d.ts.map