import { BackgroundStyle, StyledText } from '../../ui_v2/common/Common';
import { DeepPartial, PartiallyConstructible } from '../../utils/utils';
/**
Configure the captions of the user guidance hints for different scanning states.
*/
export declare class CreditCardScannerGuidanceStates extends PartiallyConstructible {
    /**
      The user guidance text displayed when no credit card is found. Initial state.
      
      Default is "?creditCardUserGuidanceNoCardFound"
      */
    noCardFound: string;
    /**
      The user guidance text displayed when a card presence was detected and scanning is in progress.
      
      Default is "?creditCardUserGuidanceScanningProgress"
      */
    scanningProgress: string;
    /**
      The user guidance text displayed when it is too dark to capture an adequate image.
      
      Default is "?creditCardUserGuidanceTooDark"
      */
    tooDark: string;
    /**
      The user guidance text displayed when the detected card is too far away and appears too small.
      
      Default is "?creditCardUserGuidanceTooSmall"
      */
    tooSmall: string;
    /**
      The user guidance text displayed when the detected card is not in a good perspective (device tilted).
      
      Default is "?creditCardUserGuidanceBadPerspective"
      */
    badPerspective: string;
    /** @param source {@displayType `DeepPartial<CreditCardScannerGuidanceStates>`} */
    constructor(source?: DeepPartial<CreditCardScannerGuidanceStates>);
}
/**
Configuration of the hints guiding users through the credit card scanning process.
*/
export declare class CreditCardScanGuidanceConfiguration extends PartiallyConstructible {
    /**
      Determines whether the user guidance hints should be visible (enabled).
      
      Default is true
      */
    visibility: boolean;
    /**
      Configure the text style for the user guidance hints.
      */
    title: StyledText;
    /**
      Configure the background style for the user guidance hints.
      */
    background: BackgroundStyle;
    /**
      Configure the captions of the user guidance hints for different states.
      */
    statesTitles: CreditCardScannerGuidanceStates;
    /** @param source {@displayType `DeepPartial<CreditCardScanGuidanceConfiguration>`} */
    constructor(source?: DeepPartial<CreditCardScanGuidanceConfiguration>);
}
//# sourceMappingURL=CreditCardScannerUserGuidance.d.ts.map