import { ButtonConfiguration, StyledText } from '../../ui_v2/common/Common';
import { DeepPartial, PartiallyConstructible } from '../../utils/utils';
/**
Determines the image for the introduction screen.
*/
export type MrzScannerIntroImage = MrzIntroDefaultImage | MrzIntroNoImage | MrzIntroCustomImage;
/**
No image for the introduction screen.
*/
export declare class MrzIntroDefaultImage extends PartiallyConstructible {
    readonly _type: 'MrzIntroDefaultImage';
    /** @param source {@displayType `DeepPartial<MrzIntroDefaultImage>`} */
    constructor(source?: DeepPartial<MrzIntroDefaultImage>);
}
/**
No image for the introduction screen.
*/
export declare class MrzIntroNoImage extends PartiallyConstructible {
    readonly _type: 'MrzIntroNoImage';
    /** @param source {@displayType `DeepPartial<MrzIntroNoImage>`} */
    constructor(source?: DeepPartial<MrzIntroNoImage>);
}
/**
A custom image for the introduction screen.
*/
export declare class MrzIntroCustomImage extends PartiallyConstructible {
    readonly _type: 'MrzIntroCustomImage';
    /**
      The web or file URI to the image.
      */
    uri: string;
    /** @param source {@displayType `DeepPartial<MrzIntroCustomImage>`} */
    constructor(source?: DeepPartial<MrzIntroCustomImage>);
}
/**
Configuration of the introduction screen for the MRZ scanner.
*/
export declare class MrzScannerIntroScreenConfiguration extends PartiallyConstructible {
    /**
      The image for the introduction screen.
      */
    image: MrzScannerIntroImage;
    /**
      The background color of the introduction screen.
      
      Default is "?sbColorSurface"
      */
    backgroundColor: string;
    /**
      The divider color of the introduction screen.
      
      Default is "?sbColorOutline"
      */
    dividerColor: string;
    /**
      The handle color of the introduction screen.
      
      Default is "?sbColorOutline"
      */
    handlerColor: string;
    /**
      Determines whether the introduction screen should automatically be shown or not when the scanning session starts.
      
      Default is false
      */
    showAutomatically: boolean;
    /**
      The title of the introduction screen, located in the top bar.
      */
    title: StyledText;
    /**
      The text explanation of the introduction screen.
      */
    explanation: StyledText;
    /**
      Configuration of the 'Done' / 'Start scanning' button.
      */
    doneButton: ButtonConfiguration;
    /** @param source {@displayType `DeepPartial<MrzScannerIntroScreenConfiguration>`} */
    constructor(source?: DeepPartial<MrzScannerIntroScreenConfiguration>);
}
//# sourceMappingURL=MRZScannerIntroScreenConfiguration.d.ts.map