import { MrzScannerConfiguration } from '../../mrz/MrzTypes';
import { ActionBarConfiguration } from '../../ui_v2/common/ActionBarConfiguration';
import { CameraConfiguration } from '../../ui_v2/common/CameraConfiguration';
import { CameraPermissionScreen } from '../../ui_v2/common/CameraPermission';
import { IconButton, Palette, Sound, Vibration } from '../../ui_v2/common/Common';
import { ScanCompletionOverlay } from '../../ui_v2/common/ScanCompletionOverlay';
import { TopBarConfiguration } from '../../ui_v2/common/TopBarConfiguration';
import { UserGuidanceConfiguration } from '../../ui_v2/common/UserGuidanceConfiguration';
import { PermanentViewFinderConfiguration } from '../../ui_v2/common/ViewFinderConfiguration';
import { MrzFinderLayoutPreset } from '../../ui_v2/mrz/MRZFinderLayoutPreset';
import { MrzScannerIntroScreenConfiguration } from '../../ui_v2/mrz/MRZScannerIntroScreenConfiguration';
import { MrzScannerScreenTextLocalization } from '../../ui_v2/mrz/MRZScannerScreenTextLocalization';
import { DeepPartial, PartiallyConstructible } from '../../utils/utils';
/**
Configuration of the screen for detecting MRZ (Machine-readable zones) of various documents.
*/
export declare class MrzScannerScreenConfiguration extends PartiallyConstructible {
    /**
      Version number of the configuration object.
      
      Default is "1.0"
      */
    readonly version: string;
    /**
      The configuration object should be applied for this screen.
      
      Default is "MrzScanner"
      */
    readonly screen: string;
    /**
      Configuration of the all strings for MRZ scanner screen.
      */
    localization: MrzScannerScreenTextLocalization;
    /**
      Define the screen's base color values from which other colors are derived.
      */
    palette: Palette;
    /**
      The background color of the MRZ scanner screen.
      
      Default is "?sbColorSurfaceLow"
      */
    backgroundColor: string;
    /**
      Configuration of the camera behavior.
      */
    cameraConfiguration: CameraConfiguration;
    /**
      Configuration of the dialog for requesting camera permissions.
      */
    cameraPermission: CameraPermissionScreen;
    /**
      Configuration of the top user guidance.
      */
    topUserGuidance: UserGuidanceConfiguration;
    /**
      Configuration of the user guidance below finder view.
      */
    finderViewUserGuidance: UserGuidanceConfiguration;
    /**
      Configuration of the top bar on the MRZ scanner screen.
      */
    topBar: TopBarConfiguration;
    /**
      Configuration of the button in the top bar that opens the introduction screen.
      */
    topBarOpenIntroScreenButton: IconButton;
    /**
      Configuration of the introduction screen for the MRZ scanner.
      */
    introScreen: MrzScannerIntroScreenConfiguration;
    /**
      Configuration of the action bar.
      */
    actionBar: ActionBarConfiguration;
    /**
      Configuration of the view finder.
      */
    viewFinder: PermanentViewFinderConfiguration;
    /**
      Configuration of the MRZ scanner.
      */
    scannerConfiguration: MrzScannerConfiguration;
    /**
      Configuration of the overlay text inside finder.
      */
    mrzExampleOverlay: MrzFinderLayoutPreset;
    /**
      Configuration of the success overlay.
      */
    successOverlay: ScanCompletionOverlay;
    /**
      Configuration of the scan confirmation sound.
      */
    sound: Sound;
    /**
      Configuration of the vibration feedback.
      */
    vibration: Vibration;
    /**
      If enabled, the screen will not turn off while the barcode scanner is active. (Android only).
      
      Default is true
      */
    keepScreenOn: boolean;
    /** @param source {@displayType `DeepPartial<MrzScannerScreenConfiguration>`} */
    constructor(source?: DeepPartial<MrzScannerScreenConfiguration>);
}
//# sourceMappingURL=MRZScannerScreenConfiguration.d.ts.map