import { ButtonConfiguration, StyledText } from '../../ui_v2/common/Common';
import { DeepPartial, PartiallyConstructible } from '../../utils/utils';
/**
The image for the introduction screen of a generic text scanner screen.
*/
export type TextPatternScannerIntroImage = TextPatternIntroGeneralField | TextPatternIntroAlphabeticField | TextPatternIntroMeterDevice | TextPatternIntroShippingContainer | TextPatternIntroNoImage | TextPatternIntroCustomImage;
/**
The image for the introduction screen featuring a general text field.
*/
export declare class TextPatternIntroGeneralField extends PartiallyConstructible {
    readonly _type: 'TextPatternIntroGeneralField';
    /** @param source {@displayType `DeepPartial<TextPatternIntroGeneralField>`} */
    constructor(source?: DeepPartial<TextPatternIntroGeneralField>);
}
/**
The image for the introduction screen featuring an alphabetic text field.
*/
export declare class TextPatternIntroAlphabeticField extends PartiallyConstructible {
    readonly _type: 'TextPatternIntroAlphabeticField';
    /** @param source {@displayType `DeepPartial<TextPatternIntroAlphabeticField>`} */
    constructor(source?: DeepPartial<TextPatternIntroAlphabeticField>);
}
/**
The image for the introduction screen featuring an electricity meter.
*/
export declare class TextPatternIntroMeterDevice extends PartiallyConstructible {
    readonly _type: 'TextPatternIntroMeterDevice';
    /** @param source {@displayType `DeepPartial<TextPatternIntroMeterDevice>`} */
    constructor(source?: DeepPartial<TextPatternIntroMeterDevice>);
}
/**
The image for the introduction screen showing a text on a shipping container.
*/
export declare class TextPatternIntroShippingContainer extends PartiallyConstructible {
    readonly _type: 'TextPatternIntroShippingContainer';
    /** @param source {@displayType `DeepPartial<TextPatternIntroShippingContainer>`} */
    constructor(source?: DeepPartial<TextPatternIntroShippingContainer>);
}
/**
No image for the introduction screen.
*/
export declare class TextPatternIntroNoImage extends PartiallyConstructible {
    readonly _type: 'TextPatternIntroNoImage';
    /** @param source {@displayType `DeepPartial<TextPatternIntroNoImage>`} */
    constructor(source?: DeepPartial<TextPatternIntroNoImage>);
}
/**
A custom image for the introduction screen.
*/
export declare class TextPatternIntroCustomImage extends PartiallyConstructible {
    readonly _type: 'TextPatternIntroCustomImage';
    /**
      The web or file URI to the image.
      */
    uri: string;
    /** @param source {@displayType `DeepPartial<TextPatternIntroCustomImage>`} */
    constructor(source?: DeepPartial<TextPatternIntroCustomImage>);
}
/**
Configuration of the introduction screen for the generic text scanner.
*/
export declare class TextPatternScannerIntroScreenConfiguration extends PartiallyConstructible {
    /**
      The image for the introduction screen.
      */
    image: TextPatternScannerIntroImage;
    /**
      The background color of the introduction screen.
      
      Default is "?sbColorSurface"
      */
    backgroundColor: string;
    /**
      The divider color of the introduction screen.
      
      Default is "?sbColorOutline"
      */
    dividerColor: string;
    /**
      The handle color of the introduction screen.
      
      Default is "?sbColorOutline"
      */
    handlerColor: string;
    /**
      Determines whether the introduction screen should automatically be shown or not when the scanning session starts.
      
      Default is false
      */
    showAutomatically: boolean;
    /**
      The title of the introduction screen, located in the top bar.
      */
    title: StyledText;
    /**
      The text explanation of the introduction screen.
      */
    explanation: StyledText;
    /**
      Configuration of the 'Done' / 'Start scanning' button.
      */
    doneButton: ButtonConfiguration;
    /** @param source {@displayType `DeepPartial<TextPatternScannerIntroScreenConfiguration>`} */
    constructor(source?: DeepPartial<TextPatternScannerIntroScreenConfiguration>);
}
//# sourceMappingURL=TextPatternScannerIntroScreenConfiguration.d.ts.map