import { TextPatternScannerConfiguration } from '../../text_pattern_scanner/TextPatternScannerTypes';
import { ActionBarConfiguration } from '../../ui_v2/common/ActionBarConfiguration';
import { CameraConfiguration } from '../../ui_v2/common/CameraConfiguration';
import { CameraPermissionScreen } from '../../ui_v2/common/CameraPermission';
import { IconButton, Palette, Sound, Vibration } from '../../ui_v2/common/Common';
import { ScanCompletionOverlay } from '../../ui_v2/common/ScanCompletionOverlay';
import { ScanbotAlertDialog } from '../../ui_v2/common/ScanbotAlertDialog';
import { TopBarConfiguration } from '../../ui_v2/common/TopBarConfiguration';
import { UserGuidanceConfiguration } from '../../ui_v2/common/UserGuidanceConfiguration';
import { PermanentViewFinderConfiguration } from '../../ui_v2/common/ViewFinderConfiguration';
import { TextPatternScannerIntroScreenConfiguration } from '../../ui_v2/textpattern/TextPatternScannerIntroScreenConfiguration';
import { TextPatternScannerScreenTextLocalization } from '../../ui_v2/textpattern/TextPatternScannerScreenTextLocalization';
import { DeepPartial, PartiallyConstructible } from '../../utils/utils';
/**
Configuration of the screen for detecting generic text data.
*/
export declare class TextPatternScannerScreenConfiguration extends PartiallyConstructible {
    /**
      Version number of the configuration object.
      
      Default is "1.0"
      */
    readonly version: string;
    /**
      The configuration object should be applied for this screen.
      
      Default is "TextPatternScanner"
      */
    readonly screen: string;
    /**
      Configuration of the all strings for generic text scanner screen.
      */
    localization: TextPatternScannerScreenTextLocalization;
    /**
      Define the screen's base color values from which other colors are derived.
      */
    palette: Palette;
    /**
      The background color of the generic text scanner screen.
      
      Default is "?sbColorSurfaceLow"
      */
    backgroundColor: string;
    /**
      Configuration of the camera behavior.
      */
    cameraConfiguration: CameraConfiguration;
    /**
      Configuration of the dialog for requesting camera permissions.
      */
    cameraPermission: CameraPermissionScreen;
    /**
      Configuration of the top user guidance.
      */
    topUserGuidance: UserGuidanceConfiguration;
    /**
      Configuration of the user guidance below finder view.
      */
    finderViewUserGuidance: UserGuidanceConfiguration;
    /**
      Configuration of the top bar on the generic text scanner screen.
      */
    topBar: TopBarConfiguration;
    /**
      Configuration of the button in the top bar that opens the introduction screen.
      */
    topBarOpenIntroScreenButton: IconButton;
    /**
      Configuration of the introduction screen for the generic text scanner screen.
      */
    introScreen: TextPatternScannerIntroScreenConfiguration;
    /**
      Configuration of the action bar.
      */
    actionBar: ActionBarConfiguration;
    /**
      Configuration of the view finder.
      */
    viewFinder: PermanentViewFinderConfiguration;
    /**
      Configuration of the scanner.
      */
    scannerConfiguration: TextPatternScannerConfiguration;
    /**
      Whether word boxes should be displayed or not.
      
      Default is true
      */
    shouldShowWordBoxes: boolean;
    /**
      The color of word boxes filling. Works best with an alpha < 0.5.
      
      Default is "#33CCE54C"
      */
    wordBoxesFillColor: string;
    /**
      The color of word boxes border lines.
      
      Default is "#33CCE599"
      */
    wordBoxesLineColor: string;
    /**
      If the confirmation alert dialog is enabled.
      
      Default is false
      */
    confirmationAlertDialogEnabled: boolean;
    /**
      Configuration of the confirmation alert dialog.
      */
    confirmationAlertDialog: ScanbotAlertDialog;
    /**
      Configuration of the result overlay.
      */
    successOverlay: ScanCompletionOverlay;
    /**
      Configuration of the scan confirmation sound.
      */
    sound: Sound;
    /**
      Configuration of the vibration feedback.
      */
    vibration: Vibration;
    /**
      If enabled, the screen will not turn off while the barcode scanner is active. (Android only).
      
      Default is true
      */
    keepScreenOn: boolean;
    /** @param source {@displayType `DeepPartial<TextPatternScannerScreenConfiguration>`} */
    constructor(source?: DeepPartial<TextPatternScannerScreenConfiguration>);
}
//# sourceMappingURL=TextPatternScannerScreenConfiguration.d.ts.map