/// Auto-generated with ScanbotSDKCodegenV3. Modifications will be overwritten.
/// Generated from core/schemas/DocumentDataExtractorConfigurationTypes.yaml

import { MrzDocumentType } from '../mrz/MrzTypes';
import { DeepPartial, PartiallyConstructible } from '../utils/utils';

/**
Base class for all generic document configuration elements.
*/
export type DocumentDataExtractorConfigurationElement =
  | DateValidationConfiguration
  | EuropeanHealthInsuranceCardConfiguration
  | MrzFallbackConfiguration
  | DocumentDataExtractorCommonConfiguration;
/** @internal */
export namespace DocumentDataExtractorConfigurationElement {
  /** @internal */
  export function From(source: { [key: string]: any }): DocumentDataExtractorConfigurationElement {
    const _type = source._type;
    switch (_type) {
      case 'DateValidationConfiguration':
        return new DateValidationConfiguration(source);
      case 'EuropeanHealthInsuranceCardConfiguration':
        return new EuropeanHealthInsuranceCardConfiguration(source);
      case 'MRZFallbackConfiguration':
        return new MrzFallbackConfiguration(source);
      case 'DocumentDataExtractorCommonConfiguration':
        return new DocumentDataExtractorCommonConfiguration(source);
      default:
        throw `Unknown child class name: ${_type}`;
    }
  }
}

/**
Date validation configuration.
This configuration element does not enable the scanning of any document types by itself.
Add to recognizer configuration to require date validation checks for specific document types.
*/
export class DateValidationConfiguration extends PartiallyConstructible {
  public readonly _type: 'DateValidationConfiguration' = 'DateValidationConfiguration';
  /**
    Minimum year that is considered valid.
    
    Default is 0
    */
  public minYear: number = 0;
  /**
    Maximum year that is considered valid.
    
    Default is 2999
    */
  public maxYear: number = 2999;
  /**
    Name, FullName, or NormalizedName of field type for which the year bounds should be applied.
    */
  public fieldTypeName: string;

  /** @param source {@displayType `DeepPartial<DateValidationConfiguration>`} */
  public constructor(source: DeepPartial<DateValidationConfiguration> = {}) {
    super();
    if (source.minYear !== undefined) {
      this.minYear = source.minYear;
    }
    if (source.maxYear !== undefined) {
      this.maxYear = source.maxYear;
    }
    if (source.fieldTypeName !== undefined) {
      this.fieldTypeName = source.fieldTypeName;
    } else {
      throw new Error('fieldTypeName must be present in constructor argument');
    }
  }
}

/**
European Health Insurance Card (EHIC) issuing country.

- `AUSTRIA`:
   Austria (Validation on the personal identification number is performed as described in "site:www.sozialversicherung.at Was ist die Versicherungsnummer?").
- `BELGIUM`:
   Belgium.
- `BULGARIA`:
   Bulgaria.
- `CROATIA`:
   Croatia.
- `CYPRUS`:
   Cyprus.
- `CZECH_REPUBLIC`:
   Czech Republic.
- `DENMARK`:
   Denmark.
- `ESTONIA`:
   Estonia.
- `FINLAND`:
   Finland.
- `FRANCE`:
   France.
- `GERMANY`:
   Germany (Validation performed according to "Spezifikation für Musterkarten und Testkarten (eGK, HBA, SMC), Anhang A" and "GS1 Struktur der Kenn-Nummer (ICCSN) der elektronischen Gesundheitskarte").
- `GREECE`:
   Greece.
- `HUNGARY`:
   Hungary.
- `IRELAND`:
   Ireland.
- `ITALY`:
   Italy.
- `LATVIA`:
   Latvia.
- `LITHUANIA`:
   Lithuania.
- `LUXEMBOURG`:
   Luxembourg.
- `MALTA`:
   Malta.
- `NETHERLANDS`:
   Netherlands.
- `POLAND`:
   Poland.
- `PORTUGAL`:
   Portugal.
- `ROMANIA`:
   Romania.
- `SLOVAKIA`:
   Slovakia.
- `SLOVENIA`:
   Slovenia.
- `SPAIN`:
   Spain.
- `SWEDEN`:
   Sweden.
- `SWITZERLAND`:
   Switzerland.
*/
export type EuropeanHealthInsuranceCardIssuingCountry =
  | 'AUSTRIA'
  | 'BELGIUM'
  | 'BULGARIA'
  | 'CROATIA'
  | 'CYPRUS'
  | 'CZECH_REPUBLIC'
  | 'DENMARK'
  | 'ESTONIA'
  | 'FINLAND'
  | 'FRANCE'
  | 'GERMANY'
  | 'GREECE'
  | 'HUNGARY'
  | 'IRELAND'
  | 'ITALY'
  | 'LATVIA'
  | 'LITHUANIA'
  | 'LUXEMBOURG'
  | 'MALTA'
  | 'NETHERLANDS'
  | 'POLAND'
  | 'PORTUGAL'
  | 'ROMANIA'
  | 'SLOVAKIA'
  | 'SLOVENIA'
  | 'SPAIN'
  | 'SWEDEN'
  | 'SWITZERLAND';

export const EuropeanHealthInsuranceCardIssuingCountryValues: EuropeanHealthInsuranceCardIssuingCountry[] =
  [
    'AUSTRIA',
    'BELGIUM',
    'BULGARIA',
    'CROATIA',
    'CYPRUS',
    'CZECH_REPUBLIC',
    'DENMARK',
    'ESTONIA',
    'FINLAND',
    'FRANCE',
    'GERMANY',
    'GREECE',
    'HUNGARY',
    'IRELAND',
    'ITALY',
    'LATVIA',
    'LITHUANIA',
    'LUXEMBOURG',
    'MALTA',
    'NETHERLANDS',
    'POLAND',
    'PORTUGAL',
    'ROMANIA',
    'SLOVAKIA',
    'SLOVENIA',
    'SPAIN',
    'SWEDEN',
    'SWITZERLAND',
  ];

/**
European Health Insurance Card (EHIC) configuration element. Add to extractor configuration to scan EHICs.
*/
export class EuropeanHealthInsuranceCardConfiguration extends PartiallyConstructible {
  public readonly _type: 'EuropeanHealthInsuranceCardConfiguration' =
    'EuropeanHealthInsuranceCardConfiguration';
  /**
    If an expected country is selected, validation rules for the given country are used,
    and if the expected country cannot be inferred or the inferred country doesn't  match the given country,
    the result of extract() will be IncompleteValidation.
    */
  public expectedCountry: EuropeanHealthInsuranceCardIssuingCountry | null = null;

  /** @param source {@displayType `DeepPartial<EuropeanHealthInsuranceCardConfiguration>`} */
  public constructor(source: DeepPartial<EuropeanHealthInsuranceCardConfiguration> = {}) {
    super();
    if (source.expectedCountry !== undefined) {
      this.expectedCountry =
        source.expectedCountry != null
          ? EuropeanHealthInsuranceCardIssuingCountryValues.includes(source.expectedCountry)
            ? source.expectedCountry
            : null
          : null;
    }
  }
}

/**
MRZ fallback configuration element.
This configuration element does not enable the scanning of any document types by itself.
Add to extractor configuration to enable recognizing the MRZ only, specifically for documents that are otherwise not supported.
Note that this may enable scanning of documents that were not enabled through the accepted document types.
*/
export class MrzFallbackConfiguration extends PartiallyConstructible {
  public readonly _type: 'MRZFallbackConfiguration' = 'MRZFallbackConfiguration';
  /**
    List of ISO 3166-1 alpha-3 country codes for which the MRZ fallback is enabled. (e.g. "DEU" for Germany).
    */
  public acceptedCountries: string[] = [];
  /**
    List of MRZ document types for which MRZ fallback is enabled.
    */
  public acceptedMRZTypes: MrzDocumentType[] = [];

  /** @param source {@displayType `DeepPartial<MrzFallbackConfiguration>`} */
  public constructor(source: DeepPartial<MrzFallbackConfiguration> = {}) {
    super();
    if (source.acceptedCountries !== undefined) {
      this.acceptedCountries = source.acceptedCountries.map((it: any) => {
        return it;
      });
    }
    if (source.acceptedMRZTypes !== undefined) {
      this.acceptedMRZTypes = source.acceptedMRZTypes.map((it: any) => {
        return it;
      });
    }
  }
}

/**
Convenience configuration element for enabling the scanning of multiple document types with a common configuration.
Add to extractor configuration to enable the scanning of multiple document types.
*/
export class DocumentDataExtractorCommonConfiguration extends PartiallyConstructible {
  public readonly _type: 'DocumentDataExtractorCommonConfiguration' =
    'DocumentDataExtractorCommonConfiguration';
  /**
    List of document types to scan. By default, the list is empty.
    */
  public acceptedDocumentTypes: string[];

  /** @param source {@displayType `DeepPartial<DocumentDataExtractorCommonConfiguration>`} */
  public constructor(source: DeepPartial<DocumentDataExtractorCommonConfiguration> = {}) {
    super();
    if (source.acceptedDocumentTypes !== undefined) {
      this.acceptedDocumentTypes = source.acceptedDocumentTypes.map((it: any) => {
        return it;
      });
    } else {
      throw new Error('acceptedDocumentTypes must be present in constructor argument');
    }
  }
}
